pub enum Entry<'a, A: Array, K> {
Occupied(OccupiedEntry<'a, A>),
Vacant(VacantEntry<'a, A, K>),
}Expand description
A view into a single entry in a set, which may either be vacant or occupied.
This enum is constructed from the entry method on SmallOrdSet.
Variants
Implementations
Sourceimpl<'a, A, K, V> Entry<'a, A, K>
impl<'a, A, K, V> Entry<'a, A, K>
Sourcepub fn or_insert(self, default: V) -> &'a mut V
pub fn or_insert(self, default: V) -> &'a mut V
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Sourcepub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V
pub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Sourcepub fn and_modify<F>(self, f: F) -> Self
pub fn and_modify<F>(self, f: F) -> Self
Provides in-place mutable access to an occupied entry before any potential inserts into the map.